@@ -16,6 +16,7 @@ def timing(
 ):
     if func is None:
         raise ValueError("No function provided")
+
     @wraps(wrapped=func)
     def wrapper(
         *args,
@@ -32,7 +33,7 @@ def timing(
 
         length = end - start
 
-        logger.log(
+        logger.report(
             f"{func.__name__} took {length:.4f} seconds",
             show=show,
         )
